(function() {
    let chatSession = null;
    let extraFields=[]
    let showCalendly=false
    function loadChatbot(clientId) {
        fetch(`http://127.0.0.1:8000/aichat/chatbot-config/${clientId}/`)
            .then(response => response.json())
            .then(config => {
                createChatbotInterface(config, clientId);
            })
            .catch(error => {
                console.error('Error fetching chatbot configuration:', error);
            });
    }

    function createChatbotInterface(config, clientId) {
        var chatbotContainer = document.createElement('div');
        chatbotContainer.id = 'gomeet-ai-sales-agent-chatbot';
        chatbotContainer.style.cssText = `
            position: fixed;
            bottom: 92px;
            ${config.widget_position === 'left' ? 'left: 20px;' : 'right: 20px;'}
            width: 400px;
            height: 550px;
            border: none;
            border-radius: 10px;
            overflow: hidden;
            font-family: Arial, sans-serif;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
            background-color: #ffffff;
            transition: all 0.3s ease-in-out;
            opacity: 0;
            transform: translateY(20px);
            pointer-events: none;
        `;

        var chatbotHeader = document.createElement('div');
        chatbotHeader.style.cssText = `
            background-color: ${config.primary_color || '#007bff'};
            color: white;
            padding: 15px;
            font-weight: bold;
            display: flex;
            justify-content: space-between;
            align-items: center;
        `;
        
        var headerLeft = document.createElement('div');
        headerLeft.style.cssText = `
            display: flex;
            align-items: center;
        `;

        if (config.company_logo) {
            var companyLogo = document.createElement('img');
            companyLogo.src = config.company_logo;
            companyLogo.style.cssText = `
                width: 30px;
                height: 30px;
                margin-right: 10px;
                border-radius: 50%;
            `;
            headerLeft.appendChild(companyLogo);
        }

        var headerText = document.createElement('span');
        headerText.textContent = config.company_name || 'GoMeet AI Sales Agent';
        headerLeft.appendChild(headerText);

        chatbotHeader.appendChild(headerLeft);

        var closeButton = document.createElement('button');
        closeButton.innerHTML = `
            <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">
                <line x1="18" y1="6" x2="6" y2="18"></line>
                <line x1="6" y1="6" x2="18" y2="18"></line>
            </svg>
        `;
        closeButton.style.cssText = `
            background: none;
            border: none;
            color: white;
            cursor: pointer;
            padding: 0;
            line-height: 1;
            display: flex;
            align-items: center;
            justify-content: center;
        `;
        closeButton.onclick = function() {
            hideChatbot();
        };
        chatbotHeader.appendChild(closeButton);

        var chatbotMessages = document.createElement('div');
        chatbotMessages.style.cssText = `
            height: 445px;
            overflow-y: auto;
            padding: 20px;
            background-color: #ffffff;
        `;

        var chatbotInputContainer = document.createElement('div');
        chatbotInputContainer.style.cssText = `
            padding: 0 15px;
            background-color: #ffffff;
            border-top: 1px solid #e5e7eb;
        `;

        var chatbotInput = document.createElement('input');
        chatbotInput.type = 'text';
        chatbotInput.placeholder = config.input_placeholder || 'Type your message...';
        chatbotInput.style.cssText = `
            width: 100%;
            padding: 10px 0;
            border: none;
            outline: none;
            font-size: 14px;
        `;

        chatbotInputContainer.appendChild(chatbotInput);

        // Add action button if enabled
        if (config.is_action_button) {
            var actionButton = document.createElement('a');
            actionButton.href = config.action_button_url;
            actionButton.target = "_blank";
            actionButton.textContent = config.action_button;
            actionButton.style.cssText = `
                display: inline-block;
                margin-top: 10px;
                padding: 5px 10px;
                background-color: ${config.primary_color || '#007bff'};
                color: white;
                text-decoration: none;
                border-radius: 4px;
                font-size: 14px;
            `;
            chatbotMessages.appendChild(actionButton);
        }

        // Add "Book a Meeting" button if enabled
        
        if (config.is_pin_meeting==true && showCalendly==false) {
            var bookMeetingButton = document.createElement('button');
            bookMeetingButton.innerHTML = '<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><rect x="3" y="4" width="18" height="18" rx="2" ry="2"></rect><line x1="16" y1="2" x2="16" y2="6"></line><line x1="8" y1="2" x2="8" y2="6"></line><line x1="3" y1="10" x2="21" y2="10"></line></svg> <span style="margin-left: 6px;">Book a meeting</span>';
            var baseStyles = `
                position: absolute;
                bottom: 60px;
                right: 20px;
                display: inline-flex;
                align-items: center;
                justify-content: center;
                padding: 8px 16px;
                background-color: #ffffff;
                color: #000000;
                border: 1px solid #e5e7eb;
                border-radius: 20px;
                font-size: 14px;
                font-weight: 500;
                cursor: pointer;
                transition: all 0.3s ease;
                box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
                z-index: 9;
            `;
            bookMeetingButton.style.cssText = `${baseStyles}`;

            bookMeetingButton.onmouseover = function() {
                this.style.backgroundColor = '#f3f4f6';
            };
            bookMeetingButton.onmouseout = function() {
                this.style.backgroundColor = '#ffffff';
            };
            bookMeetingButton.onclick = function() {
                addCalendlyIframe(config.id)
                // toggleCalendly(config.id);
            };
            
            // Append the button to the chatbot container instead of chatbotMessages
            chatbotContainer.appendChild(bookMeetingButton);
        
            // Adjust the chatbot messages container to accommodate the button
            // chatbotMessages.style.paddingBottom = '50px';
        }

        chatbotContainer.appendChild(chatbotHeader);
        chatbotContainer.appendChild(chatbotMessages);
        chatbotContainer.appendChild(chatbotInputContainer);

        var chatButton = document.createElement('button');
        chatButton.style.cssText = `
            position: fixed;
            bottom: 20px;
            ${config.widget_position === 'left' ? 'left: 20px;' : 'right: 20px;'}
            width: 50px;
            height: 50px;
            border-radius: 50%;
            background-color: ${config.primary_color || '#007bff'};
            color: white;
            border: none;
            cursor: pointer;
            box-shadow: 0 2px 6px rgba(0,0,0,0.2);
            padding: 0px;
            display: flex;
            align-items: center;
            justify-content: center;
            transition: transform 0.3s ease-in-out;
        `;

        function updateChatButtonIcon(isOpen) {
            if (isOpen) {
                chatButton.innerHTML = `
                    <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">
                        <polyline points="6 9 12 15 18 9"></polyline>
                    </svg>
                `;
                chatButton.style.transform = 'rotate(180deg)';
            } else {
                if (config.chat_icon) {
                    chatButton.innerHTML = `<img src="${config.chat_icon}" style="width: 100%; height: 100%; border-radius: 50%;">`;
                } else {
                    chatButton.textContent = 'Chat';
                }
                chatButton.style.transform = 'rotate(0deg)';
            }
        }

        function showChatbot() {
            chatbotContainer.style.opacity = '1';
            chatbotContainer.style.transform = 'translateY(0)';
            chatbotContainer.style.pointerEvents = 'auto';
            updateChatButtonIcon(true);
        }

        function hideChatbot() {
            chatbotContainer.style.opacity = '0';
            chatbotContainer.style.transform = 'translateY(20px)';
            chatbotContainer.style.pointerEvents = 'none';
            updateChatButtonIcon(false);
        }

        updateChatButtonIcon(config.widget_default_state === 'open');

        chatButton.onclick = function() {
            if (chatbotContainer.style.opacity === '0') {
                showChatbot();
            } else {
                hideChatbot();
            }
        };

        document.body.appendChild(chatbotContainer);
        document.body.appendChild(chatButton);

        // Add CSS for loader animation
        var style = document.createElement('style');
        style.textContent = `
            .loader {
                text-align: center;
            }
            .loader span {
                display: inline-block;
                vertical-align: middle;
                width: 10px;
                height: 10px;
                background: ${config.primary_color || '#007bff'};
                border-radius: 10px;
                animation: loader 0.8s infinite alternate;
            }
            .loader span:nth-of-type(2) {
                animation-delay: 0.2s;
            }
            .loader span:nth-of-type(3) {
                animation-delay: 0.6s;
            }
            @keyframes loader {
                0% {
                    opacity: 0.9;
                    transform: scale(0.5);
                }
                100% {
                    opacity: 0.1;
                    transform: scale(1);
                }
            }
        `;
        document.head.appendChild(style);

        function addMessage(text, isUser = false) {
            var messageContainer = document.createElement('div');
            messageContainer.style.cssText = `
                display: flex;
                flex-direction: column;
                margin-bottom: 15px;
                ${isUser ? 'align-items: flex-end;' : ''}
                opacity: 0;
                transform: translateY(20px);
                transition: all 0.3s ease-in-out;
            `;

            if (!isUser) {
                var agentName = document.createElement('div');
                agentName.textContent = config.agent_name || 'AI Agent';
                agentName.style.cssText = `
                    font-size: 14px;
                    color: #666;
                    margin-bottom: 5px;
                    margin-left: 48px;
                    ${isUser ? 'align-self: flex-end;' : 'align-self: flex-start;'}
                `;
                messageContainer.appendChild(agentName);
            }

            var messageContent = document.createElement('div');
            messageContent.style.cssText = `
                display: flex;
                ${isUser ? 'justify-content: flex-end;' : ''}
            `;

            if (!isUser && config.bot_avatar) {
                var avatar = document.createElement('img');
                avatar.src = config.bot_avatar;
                avatar.style.cssText = `
                    width: 30px;
                    height: 30px;
                    border-radius: 50%;
                    margin-right: 10px;
                `;
                messageContent.appendChild(avatar);
            }

            var messageElement = document.createElement('div');
            messageElement.style.cssText = `
                padding: 10px 15px;
                border-radius: 18px;
                max-width: 100%;
                font-size: 16px;
                ${isUser 
                    ? `background-color: ${config.primary_color || '#007bff'}; color: white; border-bottom-right-radius: 4px;`
                    : 'background-color: #f3f4f6; color: #000000; border-bottom-left-radius: 4px;'}
            `;
            messageElement.textContent = text;
            messageContent.appendChild(messageElement);

            messageContainer.appendChild(messageContent);
            chatbotMessages.appendChild(messageContainer);
            
            // Trigger reflow to ensure the transition works
            messageContainer.offsetHeight;
            
            messageContainer.style.opacity = '1';
            messageContainer.style.transform = 'translateY(0)';
            
            chatbotMessages.scrollTop = chatbotMessages.scrollHeight;
        }

        function addTypingIndicator() {
            var typingContainer = document.createElement('div');
            typingContainer.style.cssText = `
                display: flex;
                flex-direction: column;
                margin-bottom: 15px;
                opacity: 0;
                transform: translateY(20px);
                transition: all 0.3s ease-in-out;
            `;

            var agentName = document.createElement('div');
            agentName.textContent = config.agent_name || 'AI Agent';
            agentName.style.cssText = `
                font-size: 12px;
                color: #666;
                margin-bottom: 5px;
                margin-left: 48px;
                align-self: flex-start;
            `;
            typingContainer.appendChild(agentName);

            var typingContent = document.createElement('div');
            typingContent.style.cssText = `
                display: flex;
            `;

            if (config.bot_avatar) {
                var avatar = document.createElement('img');
                avatar.src = config.bot_avatar;
                avatar.style.cssText = `
                    width: 30px;
                    height: 30px;
                    border-radius: 50%;
                    margin-right: 10px;
                `;
                typingContent.appendChild(avatar);
            }

            var loaderElement = document.createElement('div');
            loaderElement.className = 'loader';
            loaderElement.style.cssText = `
                padding: 10px 15px;
                border-radius: 18px;
                background-color: #f3f4f6;
                border-bottom-left-radius: 4px;
            `;
            loaderElement.innerHTML = '<span></span><span></span><span></span>';

            typingContent.appendChild(loaderElement);

            typingContainer.appendChild(typingContent);
            chatbotMessages.appendChild(typingContainer);
            
            // Trigger reflow to ensure the transition works
            typingContainer.offsetHeight;
            
            typingContainer.style.opacity = '1';
            typingContainer.style.transform = 'translateY(0)';
            
            chatbotMessages.scrollTop = chatbotMessages.scrollHeight;

            return typingContainer;
        }

        async function sendUserDetailsToBackend(name, email, company_name){
            let sendData={
                name:name,
                email:email,
                company_name:company_name,
                chatSession,
                user_id:config.user_id
            }
            let values={
                name:name,
                email:email,
                company_name:company_name,
            }
            await fetch('http://127.0.0.1:8000/emailapp/store_enquiry_contact', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify(sendData)
            })
            .then(response => response.json()
            
        ).catch((error)=>alert("Something went wrong please try again!"))

            return fetch('http://127.0.0.1:8000/aichat/aichat_response/', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    chatbot_id: clientId,
                    message: `i have Submitted the form details :${JSON.stringify(values)}`,
                    chat_session: chatSession,
                })
            })
            .then(response => response.json()
            
        )
            .then(data => {
            if (data.chat_session) {
                chatSession = data.chat_session;
            }
            
                if (data.reply) {
                    addMessage(data.reply)
                    
                }
                
                else {
                    throw new Error('No reply received from the server');
                }
            });
            

        }
        function addForm() {
            const formContainer = document.createElement('div');
            formContainer.style.cssText = `
                margin-top: 15px;
                margin-bottom: 15px;
                padding: 10px;
                background-color: #f9f9f9;
                border-radius: 8px;
                border: 1px solid #e0e0e0;
            `;

            const formTitle = document.createElement('p');
            formTitle.textContent = 'Please provide your details:';
            formTitle.style.cssText = 'margin-bottom: 10px; font-weight: bold;';
            formContainer.appendChild(formTitle);

            const fields = ['name', 'email', 'company'];
            fields.forEach(field => {
                const input = document.createElement('input');
                input.placeholder = field.charAt(0).toUpperCase() + field.slice(1);
                input.style.cssText = `
                    width: 100%;
                    margin-bottom: 10px;
                    padding: 8px;
                    border: 1px solid #ccc;
                    border-radius: 4px;
                    font-size: 14px;
                `;
                input.id = `chatbot-${field}`;
                formContainer.appendChild(input);
            });

            const submitButton = document.createElement('button');
            submitButton.textContent = 'Submit';
            var submitButtonStyle= `
                background-color: ${config.primary_color || '#007bff'};
                color: white;
                border: none;
                padding: 8px 12px;
                font-size: 14px;
                border-radius: 4px;
                cursor: pointer;
            `;
            submitButton.style.cssText=submitButtonStyle
            submitButton.onclick = async function() {
                const name = document.getElementById('chatbot-name').value;
                const email = document.getElementById('chatbot-email').value;
                const company = document.getElementById('chatbot-company').value;
                if (!name || !email || !company) {
                    alert('Please fill out all fields.');
                    return;
                }
                const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
                if (!emailRegex.test(email)) {
                    alert('Please enter a valid email address.');
                    return;
                }
                if (name && email && company) {
                    submitButton.textContent='Submitting...'
                    submitButton.disabled=true
                    submitButton.style.cssText = `
                    ${submitButtonStyle}
                    background-color: #e5e7eb;
                    color: #9ca3af;
                    cursor: not-allowed;
                    opacity: 0.7;
                `;
                    await sendUserDetailsToBackend(name, email, company);
                    formContainer.remove();
                    return;
                } else {
                    alert('Please fill out all fields.');
                }
            };
            formContainer.appendChild(submitButton);

            chatbotMessages.appendChild(formContainer);
            chatbotMessages.scrollTop = chatbotMessages.scrollHeight;
        }

        function addCalendlyIframe(configId) {

            fetch(`http://127.0.0.1:8000/aichat/get_calendly_url_ai_chat`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({ document_id: configId })
            })
            .then(response => response.json())
            .then(calendlyData => {
                if (calendlyData && calendlyData.scheduling_url) {
                    showCalendly=true
                    bookMeetingButton.remove()
                    
                    const iframeContainer = document.createElement('div');
            iframeContainer.style.cssText = `
                margin-top: 15px;
                margin-bottom: 15px;
                width: 100%;
                height: 400px;
                border-radius: 8px;
                overflow: hidden;
            `;

            const calendlyIframe = document.createElement('iframe');
            calendlyIframe.src = calendlyData.scheduling_url;
            calendlyIframe.style.cssText = `
                width: 100%;
                height: 100%;
                border: none;
            `;
            
            iframeContainer.appendChild(calendlyIframe);

            chatbotMessages.appendChild(iframeContainer);
            chatbotMessages.scrollTop = chatbotMessages.scrollHeight;
                    
                    
                } else {
                    console.error('No scheduling URL in the response');
                    addMessage("I'm sorry, but I couldn't fetch the scheduling link. Please try again later or contact our support team.", false);
                }
            })
            .catch(error => {
                console.error('Error fetching Calendly URL:', error);
                addMessage("I'm sorry, but there was an error fetching the scheduling link. Please try again later or contact our support team.", false);
            });
        }


        function sendMessageToBackend(message) {

            return fetch('http://127.0.0.1:8000/aichat/aichat_response/', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    chatbot_id: clientId,
                    message: message,
                    chat_session: chatSession,
                    showCalendly:showCalendly
                })
            })
            .then(response => response.json()
            
        )
            .then(data => {
                 // Check if there's a new chat_session in the response and store it
            if (data.chat_session) {
                chatSession = data.chat_session;
            }
            
                if (data.reply) {
                    if (data.reply.toLowerCase().includes("book a meeting") || data.reply.toLowerCase().includes("schedule an appointment")) {
                        console.log("this is getting triggered");
                        
                        // toggleCalendly(config.id);
                    }
                
                
                    return {"reply":data.reply,"extra_fields":data.extra_fields};
                }
                
                else {
                    throw new Error('No reply received from the server');
                }
            });
        }

        chatbotInput.addEventListener('keypress', function(e) {
            if (e.key === 'Enter' && this.value.trim() !== '') {
                const userMessage = this.value.trim();
                addMessage(userMessage, true);
                var typingIndicator = addTypingIndicator();
                this.value = '';
                
                sendMessageToBackend(userMessage)
                    .then((data) => {
                        console.log("reply,extra_fields",data);
                        
                        chatbotMessages.removeChild(typingIndicator);
                        addMessage(data.reply);
                        if (data.extra_fields=='email_enquiry' && !extraFields.includes('email_enquiry')){
                            extraFields.push('email_enquiry')
                            addForm()
                          }
                          if (data.extra_fields === 'meeting' && !extraFields.includes('meeting')) {
                            extraFields.push('meeting');

                            addCalendlyIframe(config.id);
                        }
                        
                
                    })
                    .catch(error => {
                        console.error('Error getting response from chatbot:', error);
                        chatbotMessages.removeChild(typingIndicator);
                        addMessage("I'm sorry, I'm having trouble responding right now. Please try again later.");
                    });
            }
        });

        window.handleCalendlyEvent = function(e) {
            console.log('handleCalendlyEvent called with event:', e);
            
            if (e.origin !== "https://calendly.com") {
                console.log('Ignoring event from non-Calendly origin:', e.origin);
                return;
            }

            console.log('Calendly message event received:', e);
            
            if (e.data && e.data.event === "calendly.event_scheduled") {
                console.log('Calendly event scheduled detected');
                const eventDetails = e.data.payload;
                console.log("Calendly event details:", eventDetails);

                if (!eventDetails || !eventDetails.event || !eventDetails.invitee) {
                    console.error('Invalid event details received from Calendly');
                    addMessage("I'm sorry, there was an error processing your scheduled meeting. Please try again or contact our support team.", false);
                    return;
                }

                const eventUri = eventDetails.event.uri;
                const inviteeUri = eventDetails.invitee.uri;
                const startTime = eventDetails.event.start_time;
                const endTime = eventDetails.event.end_time;
                const inviteeEmail = eventDetails.invitee.email;
                const inviteeName = eventDetails.invitee.name;

                console.log('Scheduling meeting with backend');
                fetch(`http://127.0.0.1:8000/meetings/schedule_meeting`, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify({
                        eventUri: eventUri,
                        inviteeUri: inviteeUri,
                        startTime: startTime,
                        endTime: endTime,
                        documentId: config.id,
                        email: inviteeEmail,
                        name: inviteeName,
                        user_id: config.user_id
                    })
                })
                .then(response => {
                    console.log('Backend response status:', response.status);
                    return response.json();
                })
                .then(data => {
                    console.log('Meeting scheduled:', data);
                    addMessage("Great! Your meeting has been scheduled. You should receive a confirmation email shortly.", false);
                })
                .catch(error => {
                    console.error('Error processing Calendly event:', error);
                    addMessage("I'm sorry, there was an error scheduling your meeting. Please try again or contact our support team.", false);
                });
            }
        };

        function toggleCalendly(documentId) {
            console.log('Toggling Calendly for document:', documentId);
            fetch(`http://127.0.0.1:8000/aichat/get_calendly_url_ai_chat`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({ document_id: documentId })
            })
            .then(response => {
                console.log('Calendly URL fetch response status:', response.status);
                return response.json();
            })
            .then(data => {
                console.log('Calendly URL data:', data);
                if (data && data.scheduling_url) {
                    console.log('Initializing Calendly widget');
                    try {
                        Calendly.initPopupWidget({
                            url: data.scheduling_url,
                            parentElement: document.body,
                            prefill: {},
                            utm: {}
                        });
                        console.log('Calendly widget initialized');
                        
                        // Force a check for Calendly events
                        setTimeout(() => {
                            console.log('Forcing check for Calendly events');
                            window.postMessage({
                                event: 'calendly.test_event',
                                origin: 'https://calendly.com'
                            }, '*');
                        }, 1000);

                        addMessage("I've opened our scheduling tool for you. Please select a time that works best for you.", false);
                    } catch (error) {
                        console.error('Error initializing Calendly widget:', error);
                        window.open(data.scheduling_url, '_blank');
                        addMessage("I've opened our scheduling tool in a new tab. Please select a time that works best for you.", false);
                    }
                } else {
                    console.error('No scheduling URL in the response');
                    addMessage("I'm sorry, but I couldn't fetch the scheduling link. Please try again later or contact our support team.", false);
                }
            })
            .catch(error => {
                console.error('Error fetching Calendly URL:', error);
                addMessage("I'm sorry, but there was an error fetching the scheduling link. Please try again later or contact our support team.", false);
            });
        }

        addMessage(config.welcome_message || `Hello! I'm ${config.agent_name || 'the GoMeet AI Sales Agent'}. How can I assist you today?`);

        if (config.widget_default_state === 'open') {
            showChatbot();
        } else {
            hideChatbot();
        }
    }

    // Load Calendly script
    // var calendlyScript = document.createElement('script');
    // calendlyScript.src = 'https://assets.calendly.com/assets/external/widget.js';
    // calendlyScript.async = true;
    // calendlyScript.onload = function() {
    //     console.log('Calendly script loaded successfully');
    // };
    // calendlyScript.onerror = function() {
    //     console.error('Failed to load Calendly script');
    // };
    // document.head.appendChild(calendlyScript);

    // Get the client ID from the script tag's data attribute
    // var scripts = document.getElementsByTagName('script');
    // var currentScript = scripts[scripts.length - 1];
    // var clientId = currentScript.getAttribute('data-client-id');

    // if (clientId) {
    //     loadChatbot(clientId);
    // } else {
    //     console.error('Client ID not provided for GoMeet chatbot');
    // }

    const validSrcUrls = [
        "https://testgomeet.dbi360.com/chatbot/chat.umd.cjs",
        "https://gomeet.dbi360.com/chatbot/chat.umd.cjs",
            "http://localhost:3000/chatbot/chat.umd.cjs"
        ];

        // Find all script tags
const scripts = document.querySelectorAll('script');
// Loop through them to find the one with a matching src attribute
scripts.forEach(script => {
    // Get the src attribute of the current script
    const scriptSrc = script.getAttribute('src');
    // Check if the src is in the list of valid URLs
    if (validSrcUrls.includes(scriptSrc)) {
        console.log('Found matching script with src:', scriptSrc);

        script.addEventListener('load', function () {
        
        var clientId = script.getAttribute('data-client-id');

        if (clientId) {
            
            loadChatbot(clientId);
        } else {
            console.log('Client ID not provided dhinchak for GoMeet chatbot');
        }
    });
  
    }
    else {
        console.log('Script not found for GoMeet chatbot');
    } 
});
//     var scripts = document.querySelector('script[src="https://testgomeet.dbi360.com/chatbot/chat.umd.cjs"]');

// if (scripts) {
//     scripts.addEventListener('load', function () {
        
//         var clientId = scripts.getAttribute('data-client-id');

//         if (clientId) {
            
//             loadChatbot(clientId);
//         } else {
//             console.log('Client ID not provided dhinchak for GoMeet chatbot');
//         }
//     });
// } else {
//     console.log('Script not found for GoMeet chatbot');
// }
})();